change log for rtems (2010-06-29)

rtems-vc at rtems.org rtems-vc at rtems.org
Tue Jun 29 20:12:03 UTC 2010


 *jennifer*:
2010-06-29	Jennifer.Averett <Jennifer.Averett at OARcorp.com>

	* libcsupport/include/rtems/libio.h, libfs/Makefile.am,
	libfs/src/defaults/default_chown.c,
	libfs/src/defaults/default_evalpath.c,
	libfs/src/defaults/default_freenode.c,
	libfs/src/defaults/default_fsmount.c,
	libfs/src/defaults/default_link.c,
	libfs/src/defaults/default_mount.c,
	libfs/src/defaults/default_rename.c,
	libfs/src/defaults/default_statvfs.c,
	libfs/src/defaults/default_symlink.c,
	libfs/src/defaults/default_unlink.c,
	libfs/src/defaults/default_utime.c, libfs/src/devfs/devfs_init.c,
	libfs/src/dosfs/msdos_init.c, libfs/src/imfs/imfs_init.c,
	libfs/src/nfsclient/src/nfs.c, libfs/src/rfs/rtems-rfs-rtems.c,
	wrapup/Makefile.am: Fixed typo in default names. Added default
	methods into filesystem tables.
	* libfs/src/defaults/default_close.c,
	libfs/src/defaults/default_evaluate_link.c,
	libfs/src/defaults/default_fpathconf.c,
	libfs/src/defaults/default_fsunmount.c,
	libfs/src/defaults/default_open.c,
	libfs/src/defaults/default_unmount.c: New files.

M 1.2474  cpukit/ChangeLog
M   1.73  cpukit/libcsupport/include/rtems/libio.h
M   1.43  cpukit/libfs/Makefile.am
M    1.3  cpukit/libfs/src/defaults/default_chown.c
A    1.1  cpukit/libfs/src/defaults/default_close.c
M    1.3  cpukit/libfs/src/defaults/default_evalpath.c
A    1.1  cpukit/libfs/src/defaults/default_evaluate_link.c
A    1.1  cpukit/libfs/src/defaults/default_fpathconf.c
M    1.3  cpukit/libfs/src/defaults/default_freenode.c
M    1.3  cpukit/libfs/src/defaults/default_fsmount.c
A    1.1  cpukit/libfs/src/defaults/default_fsunmount.c
M    1.3  cpukit/libfs/src/defaults/default_link.c
M    1.3  cpukit/libfs/src/defaults/default_mount.c
A    1.1  cpukit/libfs/src/defaults/default_open.c
M    1.3  cpukit/libfs/src/defaults/default_rename.c
M    1.3  cpukit/libfs/src/defaults/default_statvfs.c
M    1.3  cpukit/libfs/src/defaults/default_symlink.c
M    1.3  cpukit/libfs/src/defaults/default_unlink.c
A    1.1  cpukit/libfs/src/defaults/default_unmount.c
M    1.3  cpukit/libfs/src/defaults/default_utime.c
M    1.6  cpukit/libfs/src/devfs/devfs_init.c
M   1.12  cpukit/libfs/src/dosfs/msdos_init.c
M   1.19  cpukit/libfs/src/imfs/imfs_init.c
M   1.22  cpukit/libfs/src/nfsclient/src/nfs.c
M   1.11  cpukit/libfs/src/rfs/rtems-rfs-rtems.c
M   1.73  cpukit/wrapup/Makefile.am

diff -u rtems/cpukit/ChangeLog:1.2473 rtems/cpukit/ChangeLog:1.2474
--- rtems/cpukit/ChangeLog:1.2473	Tue Jun 29 13:51:48 2010
+++ rtems/cpukit/ChangeLog	Tue Jun 29 14:37:27 2010
@@ -1,3 +1,28 @@
+2010-06-29	Jennifer.Averett <Jennifer.Averett at OARcorp.com>
+
+	* libcsupport/include/rtems/libio.h, libfs/Makefile.am,
+	libfs/src/defaults/default_chown.c,
+	libfs/src/defaults/default_evalpath.c,
+	libfs/src/defaults/default_freenode.c,
+	libfs/src/defaults/default_fsmount.c,
+	libfs/src/defaults/default_link.c,
+	libfs/src/defaults/default_mount.c,
+	libfs/src/defaults/default_rename.c,
+	libfs/src/defaults/default_statvfs.c,
+	libfs/src/defaults/default_symlink.c,
+	libfs/src/defaults/default_unlink.c,
+	libfs/src/defaults/default_utime.c, libfs/src/devfs/devfs_init.c,
+	libfs/src/dosfs/msdos_init.c, libfs/src/imfs/imfs_init.c,
+	libfs/src/nfsclient/src/nfs.c, libfs/src/rfs/rtems-rfs-rtems.c,
+	wrapup/Makefile.am: Fixed typo in default names. Added default
+	methods into filesystem tables.
+	* libfs/src/defaults/default_close.c,
+	libfs/src/defaults/default_evaluate_link.c,
+	libfs/src/defaults/default_fpathconf.c,
+	libfs/src/defaults/default_fsunmount.c,
+	libfs/src/defaults/default_open.c,
+	libfs/src/defaults/default_unmount.c: New files.
+
 2010-06-29	Joel Sherrill <joel.sherrill at oarcorp.com>
 
 	* configure.ac, score/include/rtems/score/percpu.h: Add

diff -u rtems/cpukit/libcsupport/include/rtems/libio.h:1.72 rtems/cpukit/libcsupport/include/rtems/libio.h:1.73
--- rtems/cpukit/libcsupport/include/rtems/libio.h:1.72	Fri Jun 25 09:23:47 2010
+++ rtems/cpukit/libcsupport/include/rtems/libio.h	Tue Jun 29 14:37:28 2010
@@ -360,6 +360,27 @@
    */
   rtems_filesystem_rmnod_t        rmnod_h;
 };
+/**
+ *  This method defines the interface to the default open(2) 
+ *  system call support which is provided by a file system 
+ *  implementation.
+ */
+int rtems_filesystem_default_open(
+  rtems_libio_t *iop,
+  const char    *pathname,
+  uint32_t       flag,
+  uint32_t       mode
+);
+
+/**
+ *  This method defines the interface to the default close(2) 
+ *  system call support which is provided by a file system 
+ *  implementation.
+ */
+int rtems_filesystem_default_close(
+  rtems_libio_t *iop
+);
+
 
 /**
  *  This method defines the interface to the default read(2) 

diff -u rtems/cpukit/libfs/Makefile.am:1.42 rtems/cpukit/libfs/Makefile.am:1.43
--- rtems/cpukit/libfs/Makefile.am:1.42	Fri Jun 25 09:23:47 2010
+++ rtems/cpukit/libfs/Makefile.am	Tue Jun 29 14:37:28 2010
@@ -16,18 +16,21 @@
 
 noinst_LIBRARIES = libdefaultfs.a
 libdefaultfs_a_SOURCES = \
-    src/defaults/default_chown.c src/defaults/default_fdatasync.c  \
-    src/defaults/default_fsync.c src/defaults/default_lseek.c \
-    src/defaults/default_rename.c src/defaults/default_unlink.c \
-    src/defaults/default_evalpath.c src/defaults/default_freenode.c \
-    src/defaults/default_ftruncate.c src/defaults/default_mount.c \
-    src/defaults/default_rmnod.c src/defaults/default_utime.c \
-    src/defaults/default_fchmod.c src/defaults/default_fsmount.c \
-    src/defaults/default_ioctl.c src/defaults/default_read.c \
-    src/defaults/default_statvfs.c  src/defaults/default_write.c \
-    src/defaults/default_fcntl.c src/defaults/default_fstat.c \
-    src/defaults/default_link.c src/defaults/default_readlink.c \
-    src/defaults/default_symlink.c
+    src/defaults/default_fchmod.c src/defaults/default_freenode.c \
+    src/defaults/default_fsync.c src/defaults/default_link.c \
+    src/defaults/default_read.c src/defaults/default_rmnod.c \
+    src/defaults/default_unlink.c src/defaults/default_chown.c \
+    src/defaults/default_fcntl.c src/defaults/default_fsmount.c \
+    src/defaults/default_ftruncate.c src/defaults/default_lseek.c \
+    src/defaults/default_readlink.c src/defaults/default_statvfs.c \
+    src/defaults/default_utime.c src/defaults/default_evalpath.c \
+    src/defaults/default_fdatasync.c  src/defaults/default_fstat.c \
+    src/defaults/default_ioctl.c src/defaults/default_mount.c \
+    src/defaults/default_rename.c src/defaults/default_symlink.c \
+    src/defaults/default_write.c src/defaults/default_fpathconf.c \
+    src/defaults/default_unmount.c src/defaults/default_evaluate_link.c \
+    src/defaults/default_open.c src/defaults/default_close.c \
+    src/defaults/default_fsunmount.c
 
 noinst_LIBRARIES += libimfs.a
 libimfs_a_SOURCES =

diff -u rtems/cpukit/libfs/src/defaults/default_chown.c:1.2 rtems/cpukit/libfs/src/defaults/default_chown.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_chown.c:1.2	Mon Jun 28 20:53:17 2010
+++ rtems/cpukit/libfs/src/defaults/default_chown.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_chown_t(
+int rtems_filesystem_default_chown(
  rtems_filesystem_location_info_t  *pathloc,       /* IN */
  uid_t                              owner,         /* IN */
  gid_t                              group          /* IN */

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_close.c:1.1
--- /dev/null	Tue Jun 29 15:12:01 2010
+++ rtems/cpukit/libfs/src/defaults/default_close.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,21 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_close(
+  rtems_libio_t *iop
+)
+{
+  rtems_set_errno_and_return_minus_one( ENOTSUP );
+}

diff -u rtems/cpukit/libfs/src/defaults/default_evalpath.c:1.2 rtems/cpukit/libfs/src/defaults/default_evalpath.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_evalpath.c:1.2	Mon Jun 28 20:53:17 2010
+++ rtems/cpukit/libfs/src/defaults/default_evalpath.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_evalpath_t(
+int rtems_filesystem_default_evalpath(
   const char                        *pathname,      /* IN     */
   size_t                             pathnamelen,   /* IN     */
   int                                flags,         /* IN     */

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_evaluate_link.c:1.1
--- /dev/null	Tue Jun 29 15:12:01 2010
+++ rtems/cpukit/libfs/src/defaults/default_evaluate_link.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,24 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_evaluate_link(
+  rtems_filesystem_location_info_t *pathloc,     /* IN/OUT */
+  int                               flags        /* IN     */
+)
+{
+  pathloc = NULL;
+  rtems_set_errno_and_return_minus_one( ENOTSUP );
+}
+

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_fpathconf.c:1.1
--- /dev/null	Tue Jun 29 15:12:01 2010
+++ rtems/cpukit/libfs/src/defaults/default_fpathconf.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,22 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_fpathconf(
+  rtems_libio_t *iop,
+  int name
+)
+{
+  rtems_set_errno_and_return_minus_one( ENOTSUP );
+}

diff -u rtems/cpukit/libfs/src/defaults/default_freenode.c:1.2 rtems/cpukit/libfs/src/defaults/default_freenode.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_freenode.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_freenode.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_freenode_t(
+int rtems_filesystem_default_freenode(
  rtems_filesystem_location_info_t      *pathloc       /* IN */
 )
 {

diff -u rtems/cpukit/libfs/src/defaults/default_fsmount.c:1.2 rtems/cpukit/libfs/src/defaults/default_fsmount.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_fsmount.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_fsmount.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_fsmount_t(
+int rtems_filesystem_default_fsmount(
   rtems_filesystem_mount_table_entry_t *mt_entry,     /* IN */
   const void                           *data          /* IN */
 )

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_fsunmount.c:1.1
--- /dev/null	Tue Jun 29 15:12:01 2010
+++ rtems/cpukit/libfs/src/defaults/default_fsunmount.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,21 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_fsunmount(
+   rtems_filesystem_mount_table_entry_t *mt_entry    /* IN */
+)
+{
+  return 0;
+}

diff -u rtems/cpukit/libfs/src/defaults/default_link.c:1.2 rtems/cpukit/libfs/src/defaults/default_link.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_link.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_link.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_link_t(
+int rtems_filesystem_default_link(
  rtems_filesystem_location_info_t  *to_loc,      /* IN */
  rtems_filesystem_location_info_t  *parent_loc,  /* IN */
  const char                        *name         /* IN */

diff -u rtems/cpukit/libfs/src/defaults/default_mount.c:1.2 rtems/cpukit/libfs/src/defaults/default_mount.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_mount.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_mount.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_mount_t (
+int rtems_filesystem_default_mount (
    rtems_filesystem_mount_table_entry_t *mt_entry     /* IN */
 )
 {

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_open.c:1.1
--- /dev/null	Tue Jun 29 15:12:02 2010
+++ rtems/cpukit/libfs/src/defaults/default_open.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,24 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_open(
+  rtems_libio_t *iop,
+  const char    *pathname,
+  uint32_t       flag,
+  uint32_t       mode
+)
+{
+  rtems_set_errno_and_return_minus_one( ENOTSUP );
+}

diff -u rtems/cpukit/libfs/src/defaults/default_rename.c:1.2 rtems/cpukit/libfs/src/defaults/default_rename.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_rename.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_rename.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_rename_t(
+int rtems_filesystem_default_rename(
  rtems_filesystem_location_info_t  *old_parent_loc,  /* IN */
  rtems_filesystem_location_info_t  *old_loc,         /* IN */
  rtems_filesystem_location_info_t  *new_parent_loc,  /* IN */

diff -u rtems/cpukit/libfs/src/defaults/default_statvfs.c:1.2 rtems/cpukit/libfs/src/defaults/default_statvfs.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_statvfs.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_statvfs.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_statvfs_t(
+int rtems_filesystem_default_statvfs(
  rtems_filesystem_location_info_t  *loc,     /* IN  */
  struct statvfs                    *buf      /* OUT */
 )

diff -u rtems/cpukit/libfs/src/defaults/default_symlink.c:1.2 rtems/cpukit/libfs/src/defaults/default_symlink.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_symlink.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_symlink.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_symlink_t(
+int rtems_filesystem_default_symlink(
  rtems_filesystem_location_info_t  *loc,         /* IN */
  const char                        *link_name,   /* IN */
  const char                        *node_name

diff -u rtems/cpukit/libfs/src/defaults/default_unlink.c:1.2 rtems/cpukit/libfs/src/defaults/default_unlink.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_unlink.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_unlink.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_unlink_t(
+int rtems_filesystem_default_unlink(
  rtems_filesystem_location_info_t  *parent_pathloc, /* IN */
  rtems_filesystem_location_info_t  *pathloc         /* IN */
 )

diff -u /dev/null rtems/cpukit/libfs/src/defaults/default_unmount.c:1.1
--- /dev/null	Tue Jun 29 15:12:02 2010
+++ rtems/cpukit/libfs/src/defaults/default_unmount.c	Tue Jun 29 14:37:28 2010
@@ -0,0 +1,21 @@
+/*
+ *  COPYRIGHT (c) 2010.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
+ */
+
+#include <rtems/libio.h>
+#include <rtems/libio_.h>
+#include <rtems/seterr.h>
+
+int rtems_filesystem_default_unmount(
+  rtems_filesystem_mount_table_entry_t *mt_entry     /* IN */
+)
+{
+  return 0;
+}

diff -u rtems/cpukit/libfs/src/defaults/default_utime.c:1.2 rtems/cpukit/libfs/src/defaults/default_utime.c:1.3
--- rtems/cpukit/libfs/src/defaults/default_utime.c:1.2	Mon Jun 28 20:53:18 2010
+++ rtems/cpukit/libfs/src/defaults/default_utime.c	Tue Jun 29 14:37:28 2010
@@ -13,7 +13,7 @@
 #include <rtems/libio_.h>
 #include <rtems/seterr.h>
 
-int rtems_filesystem_default_utime_t(
+int rtems_filesystem_default_utime(
   rtems_filesystem_location_info_t  *pathloc,       /* IN */
   time_t                             actime,        /* IN */
   time_t                             modtime        /* IN */

diff -u rtems/cpukit/libfs/src/devfs/devfs_init.c:1.5 rtems/cpukit/libfs/src/devfs/devfs_init.c:1.6
--- rtems/cpukit/libfs/src/devfs/devfs_init.c:1.5	Mon May 31 08:56:36 2010
+++ rtems/cpukit/libfs/src/devfs/devfs_init.c	Tue Jun 29 14:37:28 2010
@@ -20,21 +20,22 @@
 {
     devFS_evaluate_path,
     devFS_evaluate_for_make,
-    NULL,
-    NULL,
+    rtems_filesystem_default_link,
+    rtems_filesystem_default_unlink,
     devFS_node_type,
     devFS_mknod,
-    NULL,
-    NULL,
-    NULL,
+    rtems_filesystem_default_chown,
+    rtems_filesystem_default_freenode,
+    rtems_filesystem_default_mount,
     devFS_initialize,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL
+    rtems_filesystem_default_unmount,
+    rtems_filesystem_default_fsunmount,
+    rtems_filesystem_default_utime,
+    rtems_filesystem_default_evaluate_link,
+    rtems_filesystem_default_symlink,
+    rtems_filesystem_default_readlink,
+    rtems_filesystem_default_rename,
+    rtems_filesystem_default_statvfs 
 };
 
 
@@ -45,15 +46,15 @@
     devFS_read,
     devFS_write,
     devFS_ioctl,
-    NULL,
+    rtems_filesystem_default_lseek,
     devFS_stat,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL,
-    NULL
+    rtems_filesystem_default_fchmod,
+    rtems_filesystem_default_ftruncate,
+    rtems_filesystem_default_fpathconf,
+    rtems_filesystem_default_fsync,
+    rtems_filesystem_default_fdatasync,
+    rtems_filesystem_default_fcntl,
+    rtems_filesystem_default_rmnod
 };
 
 

diff -u rtems/cpukit/libfs/src/dosfs/msdos_init.c:1.11 rtems/cpukit/libfs/src/dosfs/msdos_init.c:1.12
--- rtems/cpukit/libfs/src/dosfs/msdos_init.c:1.11	Mon May 31 08:56:36 2010
+++ rtems/cpukit/libfs/src/dosfs/msdos_init.c	Tue Jun 29 14:37:28 2010
@@ -22,22 +22,22 @@
 const rtems_filesystem_operations_table  msdos_ops = {
   .evalpath_h     =  msdos_eval_path,
   .evalformake_h  =  msdos_eval4make,
-  .link_h         =  NULL,
+  .link_h         =  rtems_filesystem_default_link,
   .unlink_h       =  msdos_file_rmnod,
   .node_type_h    =  msdos_node_type,
   .mknod_h        =  msdos_mknod,
-  .chown_h        =  NULL,
+  .chown_h        =  rtems_filesystem_default_chown,
   .freenod_h      =  msdos_free_node_info,
-  .mount_h        =  NULL,
+  .mount_h        =  rtems_filesystem_default_mount,
   .fsmount_me_h   =  rtems_dosfs_initialize,
-  .unmount_h      =  NULL,
+  .unmount_h      =  rtems_filesystem_default_unmount,
   .fsunmount_me_h =  msdos_shut_down,
-  .utime_h        =  NULL,
-  .eval_link_h    =  NULL,
-  .symlink_h      =  NULL,
-  .readlink_h     =  NULL,
+  .utime_h        =  rtems_filesystem_default_utime,
+  .eval_link_h    =  rtems_filesystem_default_evaluate_link,
+  .symlink_h      =  rtems_filesystem_default_symlink,
+  .readlink_h     =  rtems_filesystem_default_readlink,
   .rename_h       =  msdos_rename,
-  .statvfs_h      =  NULL
+  .statvfs_h      =  rtems_filesystem_default_statvfs
 };
 
 /* msdos_initialize --

diff -u rtems/cpukit/libfs/src/imfs/imfs_init.c:1.18 rtems/cpukit/libfs/src/imfs/imfs_init.c:1.19
--- rtems/cpukit/libfs/src/imfs/imfs_init.c:1.18	Tue Jun  8 05:25:44 2010
+++ rtems/cpukit/libfs/src/imfs/imfs_init.c	Tue Jun 29 14:37:28 2010
@@ -43,7 +43,7 @@
   .symlink_h = IMFS_symlink,
   .readlink_h = IMFS_readlink,
   .rename_h = IMFS_rename,
-  .statvfs_h = NULL
+  .statvfs_h = rtems_filesystem_default_statvfs
 };
 
 int IMFS_initialize(

diff -u rtems/cpukit/libfs/src/rfs/rtems-rfs-rtems.c:1.10 rtems/cpukit/libfs/src/rfs/rtems-rfs-rtems.c:1.11
--- rtems/cpukit/libfs/src/rfs/rtems-rfs-rtems.c:1.10	Wed Jun 16 12:25:40 2010
+++ rtems/cpukit/libfs/src/rfs/rtems-rfs-rtems.c	Tue Jun 29 14:37:28 2010
@@ -1203,19 +1203,19 @@
  */
 const rtems_filesystem_file_handlers_r rtems_rfs_rtems_link_handlers =
 {
-  .open_h      = NULL,
-  .close_h     = NULL,
-  .read_h      = NULL,
-  .write_h     = NULL,
-  .ioctl_h     = NULL,
-  .lseek_h     = NULL,
+  .open_h      = rtems_filesystem_default_open,
+  .close_h     = rtems_filesystem_default_close,
+  .read_h      = rtems_filesystem_default_read,
+  .write_h     = rtems_filesystem_default_write,
+  .ioctl_h     = rtems_filesystem_default_ioctl,
+  .lseek_h     = rtems_filesystem_default_lseek,
   .fstat_h     = rtems_rfs_rtems_stat,
-  .fchmod_h    = NULL,
-  .ftruncate_h = NULL,
-  .fpathconf_h = NULL,
-  .fsync_h     = NULL,
-  .fdatasync_h = NULL,
-  .fcntl_h     = NULL,
+  .fchmod_h    = rtems_filesystem_default_fchmod,
+  .ftruncate_h = rtems_filesystem_default_ftruncate,
+  .fpathconf_h = rtems_filesystem_default_fpathconf,
+  .fsync_h     = rtems_filesystem_default_fsync,
+  .fdatasync_h = rtems_filesystem_default_fdatasync,
+  .fcntl_h     = rtems_filesystem_default_fcntl,
   .rmnod_h     = rtems_rfs_rtems_rmnod
 };
 
@@ -1240,12 +1240,12 @@
   .mknod_h        = rtems_rfs_rtems_mknod,
   .chown_h        = rtems_rfs_rtems_chown,
   .freenod_h      = rtems_rfs_rtems_freenodinfo,
-  .mount_h        = NULL,
+  .mount_h        = rtems_filesystem_default_mount,
   .fsmount_me_h   = rtems_rfs_rtems_initialise,
-  .unmount_h      = NULL,
+  .unmount_h      = rtems_filesystem_default_unmount,
   .fsunmount_me_h = rtems_rfs_rtems_shutdown,
   .utime_h        = rtems_rfs_rtems_utime,
-  .eval_link_h    = NULL, /* never called cause we lie in the node type */
+  .eval_link_h    = rtems_filesystem_default_evaluate_link, /* never called cause we lie in the node type */
   .symlink_h      = rtems_rfs_rtems_symlink,
   .readlink_h     = rtems_rfs_rtems_readlink,
   .rename_h       = rtems_rfs_rtems_rename,

diff -u rtems/cpukit/wrapup/Makefile.am:1.72 rtems/cpukit/wrapup/Makefile.am:1.73
--- rtems/cpukit/wrapup/Makefile.am:1.72	Thu Jun 17 10:29:44 2010
+++ rtems/cpukit/wrapup/Makefile.am	Tue Jun 29 14:37:28 2010
@@ -27,6 +27,7 @@
 if LIBDOSFS
 TMP_LIBS += ../libfs/libdosfs.a
 endif
+TMP_LIBS += ../libfs/libdefaultfs.a
 TMP_LIBS += ../libfs/libimfs.a
 TMP_LIBS += ../libfs/librfs.a
 


 *jennifer*:
2010-06-29	Jennifer Averett <Jennifer.Averett at OARcorp.com>

	* new-exceptions/bspsupport/ppc_exc_asm_macros.h: Added include of
	bspopts to resolve compilation problem.

M  1.356  c/src/lib/libcpu/powerpc/ChangeLog
M   1.12  c/src/lib/libcpu/powerpc/new-exceptions/bspsupport/ppc_exc_asm_macros.h

diff -u rtems/c/src/lib/libcpu/powerpc/ChangeLog:1.355 rtems/c/src/lib/libcpu/powerpc/ChangeLog:1.356
--- rtems/c/src/lib/libcpu/powerpc/ChangeLog:1.355	Mon Jun 28 19:39:39 2010
+++ rtems/c/src/lib/libcpu/powerpc/ChangeLog	Tue Jun 29 14:44:06 2010
@@ -1,3 +1,8 @@
+2010-06-29	Jennifer Averett <Jennifer.Averett at OARcorp.com>
+
+	* new-exceptions/bspsupport/ppc_exc_asm_macros.h: Added include of
+	bspopts to resolve compilation problem.
+
 2010-06-28	Joel Sherrill <joel.sherrill at oarcorp.com>
 
 	PR 1573/cpukit

diff -u rtems/c/src/lib/libcpu/powerpc/new-exceptions/bspsupport/ppc_exc_asm_macros.h:1.11 rtems/c/src/lib/libcpu/powerpc/new-exceptions/bspsupport/ppc_exc_asm_macros.h:1.12
--- rtems/c/src/lib/libcpu/powerpc/new-exceptions/bspsupport/ppc_exc_asm_macros.h:1.11	Mon Jun 28 19:39:39 2010
+++ rtems/c/src/lib/libcpu/powerpc/new-exceptions/bspsupport/ppc_exc_asm_macros.h	Tue Jun 29 14:44:06 2010
@@ -12,6 +12,7 @@
  * reintroduce such statements.
  */
 
+#include <bspopts.h>
 #include <bsp/vectors.h>
 
 #define LT(cr) ((cr)*4+0)


 *jennifer*:
2010-06-29	Jennifer.Averett <Jennifer.Averett at OARcorp.com>

	* umon/tfsDriver.c: Changed NULL methods in filesystem tables to be
	default methods.

M  1.173  c/src/lib/libbsp/shared/ChangeLog
M    1.6  c/src/lib/libbsp/shared/umon/tfsDriver.c

diff -u rtems/c/src/lib/libbsp/shared/ChangeLog:1.172 rtems/c/src/lib/libbsp/shared/ChangeLog:1.173
--- rtems/c/src/lib/libbsp/shared/ChangeLog:1.172	Fri May 28 01:18:27 2010
+++ rtems/c/src/lib/libbsp/shared/ChangeLog	Tue Jun 29 14:45:52 2010
@@ -1,3 +1,8 @@
+2010-06-29	Jennifer.Averett <Jennifer.Averett at OARcorp.com>
+
+	* umon/tfsDriver.c: Changed NULL methods in filesystem tables to be
+	default methods.
+
 2010-05-28	Ralf Corsépius <ralf.corsepius at rtems.org>
 
 	* umon/tfsDriver.c:

diff -u rtems/c/src/lib/libbsp/shared/umon/tfsDriver.c:1.5 rtems/c/src/lib/libbsp/shared/umon/tfsDriver.c:1.6
--- rtems/c/src/lib/libbsp/shared/umon/tfsDriver.c:1.5	Mon May 31 09:01:31 2010
+++ rtems/c/src/lib/libbsp/shared/umon/tfsDriver.c	Tue Jun 29 14:45:53 2010
@@ -700,37 +700,40 @@
 
 
 rtems_filesystem_operations_table  rtems_tfs_ops = {
-  rtems_tfs_eval_path,         /* eval_path */
-  rtems_tfs_evaluate_for_make, /* evaluate_for_make */
-  NULL,                        /* link */
-  NULL,                        /* unlink */
-  rtems_tfs_node_type,         /* node_type */
-  NULL,                        /* mknod */
-  NULL,                        /* chown */
-  rtems_tfs_free_node_info,    /* freenodinfo */
-  NULL,                        /* mount */
-  rtems_tfs_mount_me,          /* initialize */
-  NULL,                        /* unmount */
-  NULL,                        /* fsunmount */
-  NULL,                        /* utime */
-  NULL,                        /* evaluate_link */
-  NULL,                        /* symlink */
-  NULL,                        /* readlin */
+  rtems_tfs_eval_path,                    /* eval_path */
+  rtems_tfs_evaluate_for_make,            /* evaluate_for_make */
+  rtems_filesystem_default_link,          /* link */
+  rtems_filesystem_default_unlink,        /* unlink */
+  rtems_tfs_node_type,                    /* node_type */
+  devFS_mknod,                            /* mknod */
+  rtems_filesystem_default_chown,         /* chown */
+  rtems_tfs_free_node_info,               /* freenodinfo */
+  rtems_filesystem_default_mount,         /* mount */
+  rtems_tfs_mount_me,                     /* initialize */
+  rtems_filesystem_default_unmount,       /* unmount */
+  rtems_filesystem_default_fsunmount,     /* fsunmount */
+  rtems_filesystem_default_utime,         /* utime */
+  rtems_filesystem_default_evaluate_link, /* evaluate_link */
+  rtems_filesystem_default_symlink,       /* symlink */
+  rtems_filesystem_default_readlink,      /* readlin */
+  rtems_filesystem_default_rename,
+  rtems_filesystem_default_statvfs 
+}
 };
 
 rtems_filesystem_file_handlers_r rtems_tfs_handlers = {
-  rtems_tfs_open,      /* open */
-  rtems_tfs_close,     /* close */
-  rtems_tfs_read,      /* read */
-  rtems_tfs_write,     /* write */
-  rtems_tfs_ioctl,     /* ioctl */
-  rtems_tfs_lseek,     /* lseek */
-  NULL,                /* fstat */
-  NULL,                /* fchmod */
-  rtems_tfs_ftruncate, /* ftruncate */
-  NULL,                /* fpathconf */
-  NULL,                /* fsync */
-  NULL,                /* fdatasync */
-  NULL,                /* fcntl */
-  NULL                 /* rmnod */
+  rtems_tfs_open,                     /* open */
+  rtems_tfs_close,                    /* close */
+  rtems_tfs_read,                     /* read */
+  rtems_tfs_write,                    /* write */
+  rtems_tfs_ioctl,                    /* ioctl */
+  rtems_tfs_lseek,                    /* lseek */
+  rtems_filesystem_default_fstat,     /* fstat */
+  rtems_filesystem_default_fchmod,    /* fchmod */
+  rtems_tfs_ftruncate,                /* ftruncate */
+  rtems_filesystem_default_fpathconf, /* fpathconf */
+  rtems_filesystem_default_fsync,     /* fsync */
+  rtems_filesystem_default_fdatasync, /* fdatasync */
+  rtems_filesystem_default_fcntl,     /* fcntl */
+  rtems_filesystem_default_rmnod      /* rmnod */
 };



diff -u rtems/cpukit/libfs/src/nfsclient/src/nfs.c:1.21 rtems/cpukit/libfs/src/nfsclient/src/nfs.c:1.22
--- rtems/cpukit/libfs/src/nfsclient/src/nfs.c:1.21	Mon May 31 08:56:37 2010
+++ rtems/cpukit/libfs/src/nfsclient/src/nfs.c	Tue Jun 29 14:37:28 2010
@@ -2472,21 +2472,23 @@
 struct _rtems_filesystem_operations_table nfs_fs_ops = {
 		nfs_evalpath,		/* MANDATORY */
 		nfs_evalformake,	/* MANDATORY; may set errno=ENOSYS and return -1 */
-		nfs_link,			/* OPTIONAL; may be NULL */
-		nfs_unlink,			/* OPTIONAL; may be NULL */
-		nfs_node_type,		/* OPTIONAL; may be NULL; BUG in mount - no test!! */
-		nfs_mknod,			/* OPTIONAL; may be NULL */
-		nfs_chown,			/* OPTIONAL; may be NULL */
-		nfs_freenode,		/* OPTIONAL; may be NULL; (release node_access) */
-		nfs_mount,			/* OPTIONAL; may be NULL */
-		rtems_nfsfs_initialize,		/* OPTIONAL; may be NULL -- not used anymore */
-		nfs_unmount,		/* OPTIONAL; may be NULL */
-		nfs_fsunmount_me,	/* OPTIONAL; may be NULL */
-		nfs_utime,			/* OPTIONAL; may be NULL */
-		nfs_eval_link,		/* OPTIONAL; may be NULL */
-		nfs_symlink,		/* OPTIONAL; may be NULL */
-		nfs_readlink,		/* OPTIONAL; may be NULL */
-		NULL				/* OPTIONAL; may be NULL */
+		nfs_link,			/* OPTIONAL; may be defaulted */
+		nfs_unlink,			/* OPTIONAL; may be defaulted */
+		nfs_node_type,		/* OPTIONAL; may be defaulted; BUG in mount - no test!! */
+		nfs_mknod,			/* OPTIONAL; may be defaulted */
+		nfs_chown,			/* OPTIONAL; may be defaulted */
+		nfs_freenode,		/* OPTIONAL; may be defaulted; (release node_access) */
+		nfs_mount,			/* OPTIONAL; may be defaulted */
+		rtems_nfsfs_initialize,		/* OPTIONAL; may be defaulted -- not used anymore */
+		nfs_unmount,		/* OPTIONAL; may be defaulted */
+		nfs_fsunmount_me,	/* OPTIONAL; may be defaulted */
+		nfs_utime,			/* OPTIONAL; may be defaulted */
+		nfs_eval_link,		/* OPTIONAL; may be defaulted */
+		nfs_symlink,		/* OPTIONAL; may be defaulted */
+		nfs_readlink,		/* OPTIONAL; may be defaulted */
+		rtems_filesystem_default_rename,	/* OPTIONAL; may be defaulted */
+                rtems_filesystem_default_statvfs	/* OPTIONAL; may be defaulted */
+
 };
 
 /*****************************************
@@ -3125,58 +3127,58 @@
 /* the file handlers table */
 static
 struct _rtems_filesystem_file_handlers_r nfs_file_file_handlers = {
-		nfs_file_open,			/* OPTIONAL; may be NULL */
-		nfs_file_close,			/* OPTIONAL; may be NULL */
-		nfs_file_read,			/* OPTIONAL; may be NULL */
-		nfs_file_write,			/* OPTIONAL; may be NULL */
-		nfs_file_ioctl,			/* OPTIONAL; may be NULL */
-		nfs_file_lseek,			/* OPTIONAL; may be NULL */
-		nfs_fstat,				/* OPTIONAL; may be NULL */
-		nfs_fchmod,				/* OPTIONAL; may be NULL */
-		nfs_file_ftruncate,		/* OPTIONAL; may be NULL */
-		nfs_file_fpathconf,		/* OPTIONAL; may be NULL - UNUSED */
-		nfs_file_fsync,			/* OPTIONAL; may be NULL */
-		nfs_file_fdatasync,		/* OPTIONAL; may be NULL */
-		nfs_file_fcntl,			/* OPTIONAL; may be NULL */
-		nfs_unlink,				/* OPTIONAL; may be NULL */
+		nfs_file_open,			/* OPTIONAL; may be defaulted */
+		nfs_file_close,			/* OPTIONAL; may be defaulted */
+		nfs_file_read,			/* OPTIONAL; may be defaulted */
+		nfs_file_write,			/* OPTIONAL; may be defaulted */
+		nfs_file_ioctl,			/* OPTIONAL; may be defaulted */
+		nfs_file_lseek,			/* OPTIONAL; may be defaulted */
+		nfs_fstat,				/* OPTIONAL; may be defaulted */
+		nfs_fchmod,				/* OPTIONAL; may be defaulted */
+		nfs_file_ftruncate,		/* OPTIONAL; may be defaulted */
+		nfs_file_fpathconf,		/* OPTIONAL; may be defaulted - UNUSED */
+		nfs_file_fsync,			/* OPTIONAL; may be defaulted */
+		nfs_file_fdatasync,		/* OPTIONAL; may be defaulted */
+		nfs_file_fcntl,			/* OPTIONAL; may be defaulted */
+		nfs_unlink,				/* OPTIONAL; may be defaulted */
 };
 
 /* the directory handlers table */
 static
 struct _rtems_filesystem_file_handlers_r nfs_dir_file_handlers = {
-		nfs_dir_open,			/* OPTIONAL; may be NULL */
-		nfs_dir_close,			/* OPTIONAL; may be NULL */
-		nfs_dir_read,			/* OPTIONAL; may be NULL */
-		nfs_dir_write,			/* OPTIONAL; may be NULL */
-		nfs_dir_ioctl,			/* OPTIONAL; may be NULL */
-		nfs_dir_lseek,			/* OPTIONAL; may be NULL */
-		nfs_fstat,				/* OPTIONAL; may be NULL */
-		nfs_fchmod,				/* OPTIONAL; may be NULL */
-		nfs_dir_ftruncate,		/* OPTIONAL; may be NULL */
-		nfs_dir_fpathconf,		/* OPTIONAL; may be NULL - UNUSED */
-		nfs_dir_fsync,			/* OPTIONAL; may be NULL */
-		nfs_dir_fdatasync,		/* OPTIONAL; may be NULL */
-		nfs_dir_fcntl,			/* OPTIONAL; may be NULL */
-		nfs_dir_rmnod,				/* OPTIONAL; may be NULL */
+		nfs_dir_open,			/* OPTIONAL; may be defaulted */
+		nfs_dir_close,			/* OPTIONAL; may be defaulted */
+		nfs_dir_read,			/* OPTIONAL; may be defaulted */
+		nfs_dir_write,			/* OPTIONAL; may be defaulted */
+		nfs_dir_ioctl,			/* OPTIONAL; may be defaulted */
+		nfs_dir_lseek,			/* OPTIONAL; may be defaulted */
+		nfs_fstat,				/* OPTIONAL; may be defaulted */
+		nfs_fchmod,				/* OPTIONAL; may be defaulted */
+		nfs_dir_ftruncate,		/* OPTIONAL; may be defaulted */
+		nfs_dir_fpathconf,		/* OPTIONAL; may be defaulted - UNUSED */
+		nfs_dir_fsync,			/* OPTIONAL; may be defaulted */
+		nfs_dir_fdatasync,		/* OPTIONAL; may be defaulted */
+		nfs_dir_fcntl,			/* OPTIONAL; may be defaulted */
+		nfs_dir_rmnod,				/* OPTIONAL; may be defaulted */
 };
 
 /* the link handlers table */
 static
 struct _rtems_filesystem_file_handlers_r nfs_link_file_handlers = {
-		nfs_link_open,			/* OPTIONAL; may be NULL */
-		nfs_link_close,			/* OPTIONAL; may be NULL */
-		nfs_link_read,			/* OPTIONAL; may be NULL */
-		nfs_link_write,			/* OPTIONAL; may be NULL */
-		nfs_link_ioctl,			/* OPTIONAL; may be NULL */
-		nfs_link_lseek,			/* OPTIONAL; may be NULL */
-		nfs_fstat,				/* OPTIONAL; may be NULL */
-		nfs_fchmod,				/* OPTIONAL; may be NULL */
-		nfs_link_ftruncate,		/* OPTIONAL; may be NULL */
-		nfs_link_fpathconf,		/* OPTIONAL; may be NULL - UNUSED */
-		nfs_link_fsync,			/* OPTIONAL; may be NULL */
-		nfs_link_fdatasync,		/* OPTIONAL; may be NULL */
-		nfs_link_fcntl,			/* OPTIONAL; may be NULL */
-		nfs_unlink,				/* OPTIONAL; may be NULL */
+		nfs_link_open,			/* OPTIONAL; may be defaulted */
+		nfs_link_close,			/* OPTIONAL; may be defaulted */
+		nfs_link_read,			/* OPTIONAL; may be defaulted */
+		nfs_link_write,			/* OPTIONAL; may be defaulted */
+		nfs_link_ioctl,			/* OPTIONAL; may be defaulted */
+		nfs_link_lseek,			/* OPTIONAL; may be defaulted */
+		nfs_fstat,				/* OPTIONAL; may be defaulted */
+		nfs_fchmod,				/* OPTIONAL; may be defaulted */
+		nfs_link_ftruncate,		/* OPTIONAL; may be defaulted */
+		nfs_link_fpathconf,		/* OPTIONAL; may be defaulted - UNUSED */
+		nfs_link_fsync,			/* OPTIONAL; may be defaulted */
+		nfs_link_fdatasync,		/* OPTIONAL; may be defaulted */
+		nfs_link_fcntl,			/* OPTIONAL; may be defaulted */
+		nfs_unlink,				/* OPTIONAL; may be defaulted */
 };
 
 /* we need a dummy driver entry table to get a

--

Generated by Deluxe Loginfo [http://www.codewiz.org/projects/index.html#loginfo] 2.122 by Bernardo Innocenti <bernie at develer.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.rtems.org/pipermail/vc/attachments/20100629/6cc79e79/attachment-0001.html>


More information about the vc mailing list